==> chicken-4.5.0.tbz: include/chicken-config.h <==
/* GENERATED */
#define HAVE_DIRENT_H 1
#define HAVE_DLFCN_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_LIMITS_H 1
#define HAVE_LONG_LONG 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMORY_H 1
#define HAVE_STDINT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRERROR 1
#define HAVE_STRINGS_H 1
#define HAVE_STRING_H 1
#define HAVE_STRTOLL 1
#define HAVE_STRTOQ 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_UNISTD_H 1
#define HAVE_UNSIGNED_LONG_LONG 1
#define STDC_HEADERS 1
#define HAVE_ALLOCA 1
#define HAVE_ALLOCA_H 1
#define HAVE_GRP_H 1
#define HAVE_ERRNO_H 1
#define HAVE_SYSEXITS_H 1
#define C_STACK_GROWS_DOWNWARD 1
#define C_HACKED_APPLY
#define C_BUILD_TAG "compiled 2010-06-13 on jail-13666 (FreeBSD)"
#define C_CHICKEN_PROGRAM "chicken"
#ifndef C_INSTALL_CC
# define C_INSTALL_CC "gcc"
#endif
#ifndef C_INSTALL_CXX
# define C_INSTALL_CXX "g++"
#endif
#ifndef C_INSTALL_RC_COMPILER
# define C_INSTALL_RC_COMPILER ""
#endif
#ifndef C_INSTALL_CFLAGS
# define C_INSTALL_CFLAGS "-fno-strict-aliasing -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -Os -fomit-frame-pointer"
#endif
#ifndef C_INSTALL_LDFLAGS
# define C_INSTALL_LDFLAGS " "
#endif
#ifndef C_INSTALL_PREFIX
# define C_INSTALL_PREFIX "/usr/local"
#endif
#ifndef C_INSTALL_SHARE_HOME
# define C_INSTALL_SHARE_HOME "/usr/local/share/chicken"
#endif
#ifndef C_INSTALL_BIN_HOME
# define C_INSTALL_BIN_HOME "/usr/local/bin"
#endif
#ifndef C_INSTALL_EGG_HOME
# define C_INSTALL_EGG_HOME "/usr/local/lib/chicken/5"
#endif
#ifndef C_INSTALL_LIB_HOME
# define C_INSTALL_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_INSTALL_STATIC_LIB_HOME
# define C_INSTALL_STATIC_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_INSTALL_INCLUDE_HOME
# define C_INSTALL_INCLUDE_HOME "/usr/local/include"
#endif
#ifndef C_INSTALL_MORE_LIBS
# define C_INSTALL_MORE_LIBS "-lm"
#endif
#ifndef C_INSTALL_MORE_STATIC_LIBS
# define C_INSTALL_MORE_STATIC_LIBS "-lm"
#endif
#ifndef C_DEFAULT_TARGET_STACK_SIZE
# define C_DEFAULT_TARGET_STACK_SIZE (256*1024)
#endif
#ifndef C_DEFAULT_TARGET_HEAP_SIZE
# define C_DEFAULT_TARGET_HEAP_SIZE 0
#endif
#ifndef C_STACK_GROWS_DOWNWARD
# define C_STACK_GROWS_DOWNWARD 1
#endif
#ifndef C_TARGET_MORE_LIBS
# define C_TARGET_MORE_LIBS "-lm"
#endif
#ifndef C_TARGET_MORE_STATIC_LIBS
# define C_TARGET_MORE_STATIC_LIBS "-lm"
#endif
#ifndef C_TARGET_CC
# define C_TARGET_CC "gcc"
#endif
#ifndef C_TARGET_CXX
# define C_TARGET_CXX "g++"
#endif
#ifndef C_TARGET_RC_COMPILER
# define C_TARGET_RC_COMPILER ""
#endif
#ifndef C_TARGET_CFLAGS
# define C_TARGET_CFLAGS "-fno-strict-aliasing -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -Os -fomit-frame-pointer"
#endif
#ifndef C_TARGET_LDFLAGS
# define C_TARGET_LDFLAGS " "
#endif
#ifndef C_CROSS_CHICKEN
# define C_CROSS_CHICKEN 0
#endif
#ifndef C_TARGET_BIN_HOME
# define C_TARGET_BIN_HOME "/usr/local/bin"
#endif
#ifndef C_TARGET_LIB_HOME
# define C_TARGET_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_TARGET_RUN_LIB_HOME
# define C_TARGET_RUN_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_TARGET_SHARE_HOME
# define C_TARGET_SHARE_HOME "/usr/local/share"
#endif
#ifndef C_TARGET_INCLUDE_HOME
# define C_TARGET_INCLUDE_HOME "/usr/local/include"
#endif
#ifndef C_TARGET_STATIC_LIB_HOME
# define C_TARGET_STATIC_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_CHICKEN_PROGRAM
# define C_CHICKEN_PROGRAM "chicken"
#endif
#ifndef C_CSC_PROGRAM
# define C_CSC_PROGRAM "csc"
#endif
#ifndef C_CSI_PROGRAM
# define C_CSI_PROGRAM "csi"
#endif
#ifndef C_CHICKEN_BUG_PROGRAM
# define C_CHICKEN_BUG_PROGRAM "chicken-bug"
#endif
#ifndef C_CHICKEN_INSTALL_PROGRAM
# define C_CHICKEN_INSTALL_PROGRAM "chicken-install"
#endif
#ifndef C_CHICKEN_UNINSTALL_PROGRAM
# define C_CHICKEN_UNINSTALL_PROGRAM "chicken-uninstall"
#endif
#ifndef C_CHICKEN_STATUS_PROGRAM
# define C_CHICKEN_STATUS_PROGRAM "chicken-status"
#endif
#ifndef C_WINDOWS_SHELL
# define C_WINDOWS_SHELL 0
#endif
#ifndef C_BINARY_VERSION
# define C_BINARY_VERSION 5
#endif
#ifndef C_BRANCH_NAME
# define C_BRANCH_NAME ""
#endif
/* END OF FILE */

==> chicken-4.6.0.tbz: include/chicken-config.h <==
/* GENERATED */
#define HAVE_DIRENT_H 1
#define HAVE_DLFCN_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_LIMITS_H 1
#define HAVE_LONG_LONG 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMORY_H 1
#define HAVE_STDINT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRERROR 1
#define HAVE_STRINGS_H 1
#define HAVE_STRING_H 1
#define HAVE_STRTOLL 1
#define HAVE_STRTOQ 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_UNISTD_H 1
#define HAVE_UNSIGNED_LONG_LONG 1
#define STDC_HEADERS 1
#define HAVE_ALLOCA 1
#define HAVE_ALLOCA_H 1
#define HAVE_GRP_H 1
#define HAVE_ERRNO_H 1
#define HAVE_SYSEXITS_H 1
#define C_STACK_GROWS_DOWNWARD 1
#define C_HACKED_APPLY
#define C_BUILD_TAG "compiled 2010-12-13 on jail-3 (FreeBSD)"
#define C_CHICKEN_PROGRAM "chicken"
#ifndef C_INSTALL_CC
# define C_INSTALL_CC "gcc"
#endif
#ifndef C_INSTALL_CXX
# define C_INSTALL_CXX "g++"
#endif
#ifndef C_INSTALL_RC_COMPILER
# define C_INSTALL_RC_COMPILER ""
#endif
#ifndef C_INSTALL_CFLAGS
# define C_INSTALL_CFLAGS "-fno-strict-aliasing -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -O2 -pipe -fno-strict-aliasing"
#endif
#ifndef C_INSTALL_LDFLAGS
# define C_INSTALL_LDFLAGS " "
#endif
#ifndef C_INSTALL_PREFIX
# define C_INSTALL_PREFIX "/usr/local"
#endif
#ifndef C_INSTALL_SHARE_HOME
# define C_INSTALL_SHARE_HOME "/usr/local/share/chicken"
#endif
#ifndef C_INSTALL_BIN_HOME
# define C_INSTALL_BIN_HOME "/usr/local/bin"
#endif
#ifndef C_INSTALL_EGG_HOME
# define C_INSTALL_EGG_HOME "/usr/local/lib/chicken/5"
#endif
#ifndef C_INSTALL_LIB_HOME
# define C_INSTALL_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_INSTALL_STATIC_LIB_HOME
# define C_INSTALL_STATIC_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_INSTALL_INCLUDE_HOME
# define C_INSTALL_INCLUDE_HOME "/usr/local/include"
#endif
#ifndef C_INSTALL_MORE_LIBS
# define C_INSTALL_MORE_LIBS "-lm"
#endif
#ifndef C_INSTALL_MORE_STATIC_LIBS
# define C_INSTALL_MORE_STATIC_LIBS "-lm"
#endif
#ifndef C_DEFAULT_TARGET_STACK_SIZE
# define C_DEFAULT_TARGET_STACK_SIZE (128*1024)
#endif
#ifndef C_DEFAULT_TARGET_HEAP_SIZE
# define C_DEFAULT_TARGET_HEAP_SIZE 0
#endif
#ifndef C_STACK_GROWS_DOWNWARD
# define C_STACK_GROWS_DOWNWARD 1
#endif
#ifndef C_TARGET_MORE_LIBS
# define C_TARGET_MORE_LIBS "-lm"
#endif
#ifndef C_TARGET_MORE_STATIC_LIBS
# define C_TARGET_MORE_STATIC_LIBS "-lm"
#endif
#ifndef C_TARGET_CC
# define C_TARGET_CC "gcc"
#endif
#ifndef C_TARGET_CXX
# define C_TARGET_CXX "g++"
#endif
#ifndef C_TARGET_RC_COMPILER
# define C_TARGET_RC_COMPILER ""
#endif
#ifndef C_TARGET_CFLAGS
# define C_TARGET_CFLAGS "-fno-strict-aliasing -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -O2 -pipe -fno-strict-aliasing"
#endif
#ifndef C_TARGET_LDFLAGS
# define C_TARGET_LDFLAGS " "
#endif
#ifndef C_TARGET_FEATURES
# define C_TARGET_FEATURES ""
#endif
#ifndef C_CROSS_CHICKEN
# define C_CROSS_CHICKEN 0
#endif
#ifndef C_TARGET_PREFIX
# define C_TARGET_PREFIX "/usr/local"
#endif
#ifndef C_TARGET_BIN_HOME
# define C_TARGET_BIN_HOME "/usr/local/bin"
#endif
#ifndef C_TARGET_LIB_HOME
# define C_TARGET_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_TARGET_RUN_LIB_HOME
# define C_TARGET_RUN_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_TARGET_SHARE_HOME
# define C_TARGET_SHARE_HOME "/usr/local/share"
#endif
#ifndef C_TARGET_INCLUDE_HOME
# define C_TARGET_INCLUDE_HOME "/usr/local/include"
#endif
#ifndef C_TARGET_STATIC_LIB_HOME
# define C_TARGET_STATIC_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_CHICKEN_PROGRAM
# define C_CHICKEN_PROGRAM "chicken"
#endif
#ifndef C_CSC_PROGRAM
# define C_CSC_PROGRAM "csc"
#endif
#ifndef C_CSI_PROGRAM
# define C_CSI_PROGRAM "csi"
#endif
#ifndef C_CHICKEN_BUG_PROGRAM
# define C_CHICKEN_BUG_PROGRAM "chicken-bug"
#endif
#ifndef C_CHICKEN_INSTALL_PROGRAM
# define C_CHICKEN_INSTALL_PROGRAM "chicken-install"
#endif
#ifndef C_CHICKEN_UNINSTALL_PROGRAM
# define C_CHICKEN_UNINSTALL_PROGRAM "chicken-uninstall"
#endif
#ifndef C_CHICKEN_STATUS_PROGRAM
# define C_CHICKEN_STATUS_PROGRAM "chicken-status"
#endif
#ifndef C_WINDOWS_SHELL
# define C_WINDOWS_SHELL 0
#endif
#ifndef C_BINARY_VERSION
# define C_BINARY_VERSION 5
#endif
#ifndef C_BRANCH_NAME
# define C_BRANCH_NAME ""
#endif
/* END OF FILE */
